| check_year | R Documentation |
Checks if year is valid
check_year(year = NULL, single = FALSE)
year |
Year. |
single |
Logical for whether year should be a single element or can be a vector of multiple years. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.