View source: R/conference_stats.R
| conference_stats | R Documentation |
This is a wrapper around group_stats() that extracts season, match, or pbp
data from players in all teams in the chosen conference. For season stats,
it aggregates all player data and team data into separate data frames and
combines them into a list. For match and pbp stats, it aggregates into a
data frame.
Conferences names can be found in
ncaa_conferences.
conference_stats(
year = NULL,
conf = NULL,
level = NULL,
sport = "WVB",
save = FALSE,
path = ".",
delay = 2
)
year |
Numeric vector of years for fall of desired seasons. |
conf |
NCAA conference name. |
level |
Character string defining whether to aggregate "teamseason", "teammatch", "playermatch", or match play-by-play ("pbp") data. |
sport |
Three letter abbreviation for NCAA sport (must be upper case; for example "WVB" for women's volleyball and "MVB" for men's volleyball). |
save |
Logical for whether to save the statistics locally as CSVs (default FALSE). |
path |
Character string of path to save statistics files. |
delay |
Numeric for time delay between teams/contests in seconds. |
For season level, returns list with data frames of player statistics and team statistics. For match and pbp levels, returns data frame of player statistics and play-by-play information respectively.
This function requires internet connectivity as it checks the
NCAA website for information.
It also uses the {chromote} package
and requires Google Chrome to be
installed.
Other functions that aggregate statistics:
division_stats(),
group_stats()
conference_stats(year = 2024, conf = "Peach Belt", level = "teamseason")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.