View source: R/find_team_contests.R
| find_team_contests | R Documentation |
NCAA datasets use a unique ID for each sport, team, season, and match. This function returns a data frame of dates, opponent team names, and contest IDs for each NCAA contest (volleyball match) for each team and season.
find_team_contests(team_id = NULL)
team_id |
Team ID determined by NCAA for season. To find ID, use
|
Returns a data frame that includes date, team, opponent, and contest ID for each season's contest.
This function requires internet connectivity as it checks the
NCAA website for information.
It also uses the {chromote} package
and requires Google Chrome to be
installed.
find_team_contests(team_id = "585290")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.