find_team_id: Find team ID for season

View source: R/find_team_id.R

find_team_idR Documentation

Find team ID for season

Description

NCAA datasets use a unique ID for each team and season. To access a team's data, we must know the volleyball team ID. This function looks up the team ID from wvb_teams or mvb_teams using the team name. Team names can be found in ncaa_teams or searched with find_team_name().

Usage

find_team_id(team = NULL, year = NULL, sport = "WVB")

Arguments

team

Name of school. Must match name used by NCAA. Find exact team name with find_team_name().

year

Numeric vector of years for fall of desired seasons.

sport

Three letter abbreviation for NCAA sport (must be upper case; for example "WVB" for women's volleyball and "MVB" for men's volleyball).

Value

Returns a character string of team ID.

Note

This function requires internet connectivity as it checks the NCAA website for information.

See Also

Other search functions: find_team_name()

Examples


find_team_id(team = "Nebraska", year = 2024)
find_team_id(team = "UCLA", year = 2023, sport = "MVB")


ncaavolleyballr documentation built on Jan. 8, 2026, 1:07 a.m.