find_team_name: Match pattern to find team names

View source: R/find_team_name.R

find_team_nameR Documentation

Match pattern to find team names

Description

This is a convenience function to find NCAA team names in ncaa_teams. Once the proper team name is found, it can be passed to find_team_id() or group_stats().

Usage

find_team_name(pattern = NULL)

Arguments

pattern

Character string of pattern you want to find in the vector of team names.

Value

Returns a character vector of team names that include the submitted pattern.

Note

This function requires internet connectivity as it checks the NCAA website for information.

See Also

Other search functions: find_team_id()

Examples


find_team_name(pattern = "Neb")


ncaavolleyballr documentation built on Jan. 8, 2026, 1:07 a.m.