match_pbp: Extract play-by-play information for a particular match

View source: R/match_pbp.R

match_pbpR Documentation

Extract play-by-play information for a particular match

Description

The NCAA's page for a match/contest includes a tab called "Play By Play". This function extracts the tables of play-by-play information for each set.

Usage

match_pbp(contest = NULL)

Arguments

contest

Contest ID determined by NCAA for match. To find ID, use find_team_contests() for a team and season.

Value

Returns a data frame of set number, teams, score, event, and player responsible for the event.

Note

This function requires internet connectivity as it checks the NCAA website for information. It also uses the {chromote} package and requires Google Chrome to be installed.

Examples


match_pbp(contest = "6080706")


ncaavolleyballr documentation built on Jan. 8, 2026, 1:07 a.m.