View source: R/player_match_stats.R
| player_match_stats | R Documentation |
The NCAA's page for a match/contest includes a tab called "Individual Statistics". This function extracts the tables of player match statistics for both home and away teams, as well as team statistics (though these can be omitted). If a particular team is specified, only that team's statistics will be returned.
player_match_stats(
contest = NULL,
team = NULL,
team_stats = TRUE,
sport = "WVB"
)
contest |
Contest ID determined by NCAA for match. To find ID, use
|
team |
Name of school. Must match name used by NCAA. Find exact team
name with |
team_stats |
Logical indicating whether to include (TRUE) or exclude (FALSE) team statistics. Default includes team statistics with player statistics. |
sport |
Three letter abbreviation for NCAA sport (must be upper case; for example "WVB" for women's volleyball and "MVB" for men's volleyball). |
By default, returns data frame that includes both home and away team match statistics. If team is specified, only that team's data are returned.
This function requires internet connectivity as it checks the
NCAA website for information.
It also uses the {chromote} package
and requires Google Chrome to be
installed.
Other functions that extract player statistics:
player_season_stats()
player_match_stats(contest = "6080706")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.