View source: R/player_season_stats.R
| player_season_stats | R Documentation |
The NCAA's main page for a team includes a tab called "Team Statistics". This function extracts the table of player statistics for the season, as well as team and opponent statistics (though these can be omitted).
player_season_stats(team_id, team_stats = TRUE)
team_id |
Team ID determined by NCAA for season. To find ID, use
|
team_stats |
Logical indicating whether to include (TRUE) or exclude (FALSE) team statistics. Default includes team statistics with player statistics. |
Returns a data frame of player statistics. Note that hometown and high school were added in 2024.
This function requires internet connectivity as it checks the
NCAA website for information.
It also uses the {chromote} package
and requires Google Chrome to be
installed.
Other functions that extract player statistics:
player_match_stats()
player_season_stats(team_id = "585290")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.