View source: R/team_match_stats.R
| team_match_stats | R Documentation |
The NCAA's main page for a team includes a tab called "Game By Game" and a section called "Game by Game Stats". This function extracts the team's summary statistics for each match of the season.
team_match_stats(team_id = NULL, sport = "WVB")
team_id |
Team ID determined by NCAA for season. To find ID, use
|
sport |
Three letter abbreviation for NCAA sport (must be upper case; for example "WVB" for women's volleyball and "MVB" for men's volleyball). |
Returns a data frame of summary team statistics for each match of the season.
This function requires internet connectivity as it checks the
NCAA website for information.
It also uses the {chromote} package
and requires Google Chrome to be
installed.
Other functions that extract team statistics:
team_season_info(),
team_season_stats()
team_match_stats(team_id = "585290")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.