team_season_info: Extract arena, coach, record, and schedule information for a...

View source: R/team_season_info.R

team_season_infoR Documentation

Extract arena, coach, record, and schedule information for a particular team and season

Description

The NCAA's main page for a team includes a tab called "Schedule/Results". This function extracts information about the team's venue, coach, and records, as well as the table of the schedule and results. This returns a list, so you can subset specific components with $ (e.g., for coach information from an object called output, use output$coach).

Usage

team_season_info(team_id = NULL)

Arguments

team_id

Team ID determined by NCAA for season. To find ID, use find_team_id().

Value

Returns a list that includes arena, coach, schedule, and record information.

Note

This function requires internet connectivity as it checks the NCAA website for information. It also uses the {chromote} package and requires Google Chrome to be installed.

See Also

Other functions that extract team statistics: team_match_stats(), team_season_stats()

Examples


team_season_info(team_id = "585290")


ncaavolleyballr documentation built on Jan. 8, 2026, 1:07 a.m.