View source: R/team_season_stats.R
| team_season_stats | R Documentation |
The NCAA's main page for a team includes a tab called "Game By Game" and a section called "Career Totals". This function extracts season summary stats.
team_season_stats(team = NULL, opponent = FALSE, sport = "WVB")
team |
Name of school. Must match name used by NCAA. Find exact team
name with |
opponent |
Logical indicating whether to include team's stats (FALSE) or opponent's stats (TRUE). Default is set to FALSE, returning team stats. |
sport |
Three letter abbreviation for NCAA sport (must be upper case; for example "WVB" for women's volleyball and "MVB" for men's volleyball). |
Returns a data frame of summary team statistics for each season.
This function requires internet connectivity as it checks the
NCAA website for information.
It also uses the {chromote} package
and requires Google Chrome to be
installed.
Other functions that extract team statistics:
team_match_stats(),
team_season_info()
team_season_stats(team = "Nebraska")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.