View source: R/find_team_name.R
| find_team_name | R Documentation |
This is a convenience function to find NCAA team names in
ncaa_teams. Once the proper team name is found, it can be
passed to find_team_id() or group_stats().
find_team_name(pattern = NULL)
pattern |
Character string of pattern you want to find in the vector of team names. |
Returns a character vector of team names that include the submitted pattern.
This function requires internet connectivity as it checks the NCAA website for information.
Other search functions:
find_team_id()
find_team_name(pattern = "Neb")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.