NCAA datasets use a unique ID for each sport, team, and season.
This function extracts team names, IDs, and conferences for each NCAA team in
a division. However, you should not need to use this function for volleyball
data from 2020-2024, as it has been used to generate wvb_teams
and mvb_teams. However, it is available to use for other
sports, using the appropriate three letter sport code drawn from
ncaa_sports (e.g., men's baseball is "MBA").