| match_pbp | R Documentation |
The NCAA's page for a match/contest includes a tab called "Play By Play". This function extracts the tables of play-by-play information for each set.
match_pbp(contest = NULL)
contest |
Contest ID determined by NCAA for match. To find ID, use
|
Returns a data frame of set number, teams, score, event, and player responsible for the event.
This function requires internet connectivity as it checks the
NCAA website for information.
It also uses the {chromote} package
and requires Google Chrome to be
installed.
match_pbp(contest = "6080706")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.