View source: R/team_season_info.R
| team_season_info | R Documentation |
The NCAA's main page for a team includes a tab called "Schedule/Results".
This function extracts information about the team's venue, coach, and
records, as well as the table of the schedule and results. This returns a
list, so you can subset specific components with $ (e.g., for coach
information from an object called output, use output$coach).
team_season_info(team_id = NULL)
team_id |
Team ID determined by NCAA for season. To find ID, use
|
Returns a list that includes arena, coach, schedule, and record information.
This function requires internet connectivity as it checks the
NCAA website for information.
It also uses the {chromote} package
and requires Google Chrome to be
installed.
Other functions that extract team statistics:
team_match_stats(),
team_season_stats()
team_season_info(team_id = "585290")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.